@@ -1,9 +1,14 @@
 # ----------------------------------------------------------------------------------------------------------------------
 # - Package Imports -
 # ----------------------------------------------------------------------------------------------------------------------
-import AthenaCSS.Library.PropertyLibrary as PropertyLibrary
-import AthenaCSS.Library.SubPropertyLibrary as SubPropertyLibrary
-import AthenaCSS.Library.SelectorElementLibrary as SelectorElementLibrary
+
+# Base classes
+from AthenaCSS.Declarations.CSSProperty import CSSProperty
+from AthenaCSS.Declarations.CSSPropertyShorthand import CSSPropertyShorthand
+
+from AthenaCSS.Generator.CSSGenerator import CSSGenerator
+from AthenaCSS.Generator.CSSGeneratorContent import CSSRule, CSSComment, CSSCommentSeparator, CSSEmptyLine
+from AthenaCSS.Generator.ConsoleColorGuide import ConsoleColorGuide
 
 from AthenaCSS.Selectors.CSSAttribute import CSSAttribute
 from AthenaCSS.Selectors.CSSClass import CSSClass
@@ -11,6 +16,8 @@ from AthenaCSS.Selectors.CSSElement import CSSElement
 from AthenaCSS.Selectors.CSSId import CSSId
 from AthenaCSS.Selectors.CSSPseudo import CSSPseudo
 
-from AthenaCSS.Declarations.CSSProperty import CSSProperty
-from AthenaCSS.Declarations.CSSPropertyShorthand import CSSPropertyShorthand
+# Library of predefined objects
+import AthenaCSS.Library.PropertyLibrary as PropertyLibrary
+import AthenaCSS.Library.SubPropertyLibrary as SubPropertyLibrary
+import AthenaCSS.Library.SelectorElementLibrary as SelectorElementLibrary
 
